from cpl_core.configuration import ConfigurationABC
from cpl_core.dependency_injection import ServiceProviderABC
from cpl_discord.application import DiscordBotApplicationABC
from cpl_discord.service import DiscordBotServiceABC
from cpl_translation import TranslationSettings, TranslationServiceABC


class TestApplication(DiscordBotApplicationABC):

    def __init__(self, config: ConfigurationABC, services: ServiceProviderABC):
        DiscordBotApplicationABC.__init__(self, config, services)

        self._config = config
        self._services = services

        self._bot: DiscordBotServiceABC = services.get_service(DiscordBotServiceABC)
        self._translation: TranslationServiceABC = services.get_service(TranslationServiceABC)

    @property
    def config(self) -> ConfigurationABC:
        return self._config

    @property
    def services(self) -> ServiceProviderABC:
        return self._services

    async def configure(self):
        self._translation.load_by_settings(self._configuration.get_configuration(TranslationSettings))

    async def main(self):
        await self._bot.start_async()

    async def stop_async(self):
        await self._bot.close()
